customscriptsbootstrap

package
v1.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 8, 2026 License: Apache-2.0, Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

const (
	ImageFamilyOSSKUUbuntu2004  = "Ubuntu2004"
	ImageFamilyOSSKUUbuntu2204  = "Ubuntu2204"
	ImageFamilyOSSKUUbuntu2404  = "Ubuntu2404"
	ImageFamilyOSSKUAzureLinux2 = "AzureLinux2"
	ImageFamilyOSSKUAzureLinux3 = "AzureLinux3"
)

Variables

This section is empty.

Functions

func ConvertContainerLogMaxSizeToMB added in v1.6.7

func ConvertContainerLogMaxSizeToMB(containerLogMaxSize string) *int32

func ConvertPodMaxPids added in v1.6.7

func ConvertPodMaxPids(podPidsLimit *int64) *int32

Types

type Bootstrapper

type Bootstrapper interface {
	GetCustomDataAndCSE(ctx context.Context) (string, string, error)
}

Bootstrapper can be implemented to generate a bootstrap script that uses the params from the Bootstrap type for a specific bootstrapping method.

type ProvisionClientBootstrap

type ProvisionClientBootstrap struct {
	ClusterName                    string
	KubeletConfig                  *bootstrap.KubeletConfiguration
	Taints                         []v1.Taint        `hash:"set"`
	StartupTaints                  []v1.Taint        `hash:"set"`
	Labels                         map[string]string `hash:"set"`
	SubnetID                       string
	Arch                           string
	SubscriptionID                 string
	ClusterResourceGroup           string
	ResourceGroup                  string
	KubeletClientTLSBootstrapToken string
	KubernetesVersion              string
	ImageDistro                    string
	IsWindows                      bool
	InstanceType                   *cloudprovider.InstanceType
	StorageProfile                 string
	OSSKU                          string
	NodeBootstrappingProvider      types.NodeBootstrappingAPI
	GPUDriverInstallationEnabled   bool
	FIPSMode                       *v1beta1.FIPSMode
	LocalDNSProfile                *v1beta1.LocalDNS
	ArtifactStreaming              *v1beta1.ArtifactStreaming
	LinuxOSConfig                  *v1beta1.LinuxOSConfiguration
}

func (*ProvisionClientBootstrap) ConstructProvisionValues added in v1.5.0

func (p *ProvisionClientBootstrap) ConstructProvisionValues(ctx context.Context) (*models.ProvisionValues, error)

ATTENTION!!!: changes here may NOT be effective on AKS machine nodes (ProvisionModeAKSMachineAPI); See aksmachineinstance.go/aksmachineinstancehelpers.go. Refactoring for code unification is not being invested immediately.

func (ProvisionClientBootstrap) GetCustomDataAndCSE

func (p ProvisionClientBootstrap) GetCustomDataAndCSE(ctx context.Context) (string, string, error)

Jump to